@@ -1,20 +1,19 @@
 #coding: utf-8
-import base64
-import os, sys
+
+import os, sys, json
 import requests, traceback
 import argparse, shlex, platform
+import importlib
 
 from prompt_toolkit import prompt
 from requests import get, post, put, delete
-from json import loads, dumps
-from base64 import b64decode, b64encode
 
 if __name__ == "__main__":
     from utils import gitee
     from utils.backend import URL, SqleeData, SqleeColumn, SqleeTable
 else:
-    from utils import gitee
-    from utils.backend import URL, SqleeData, SqleeColumn, SqleeTable
+    from .utils import gitee
+    from .utils.backend import URL, SqleeData, SqleeColumn, SqleeTable
 from prompt_toolkit.output.win32 import NoConsoleScreenBufferError
 
 class termios:
@@ -34,8 +33,8 @@ class objects:
             return SqleeTable(name=name, repo=self.obj.repo)
         raise ValueError("目标表不存在.")
 
-    def create(self, *args, **kwargs):
-        return self.obj.create_table(*args, **kwargs)
+    def create(self, name=None, namespace=None):
+        return self.obj.create_table(name=name, namespace=namespace)
 
     def delete(self, *args, **kwargs):
         return self.obj.drop_table(*args, **kwargs)
@@ -43,6 +42,10 @@ class objects:
     def count(self):
         return len(self.obj.repo.list_folder(path="", detail=True))
 
+    @property
+    def count(self):
+        return len(self.obj.repo.list_folder(path="", detail=True))
+
 class Sqlee:
     access_token = None
     repo = None
@@ -58,62 +61,34 @@ class Sqlee:
         tables = [SqleeTable(name=data['name'], repo=self.repo) for data in datas if data['type'] == 'dir']
         return tables
 
-    def create_table(self, name=None):
-        return self.repo.make_folder(path=name)
+    def create_table(self, name=None, namespace=None):
+        for i in namespace:
+            if i == "id":
+                raise NameError("命名域不可使用'id'参数.")
+        make = self.repo.make_folder(path=name)
+        self.repo.upload_file(path=name+"/"+".namespace", content=json.dumps(namespace))
+        return make
 
     def drop_table(self, name=None):
         return self.repo.drop_folder(path=name)
 
-    def filter(self, table_name, blurry=False, **kwargs):
-        if True:
-            print("该功能目前正在更新，故禁止使用. (已拦截)")
-            return
-        # 返回完全匹配的 一条数据即对象编号也就是id(就是表下面的 对象id) 但返回的是元组 ,当然可用于 update_data 函数
-        # self.filtet(table_name,kwargs={0:'123'，})
-
-        query_list = []
-        if kwargs:
-
-            data = self.select_data(
-                table_name=table_name,
-                columns=[c for c in kwargs['kwargs'].keys()]
-            )
-
-            columns = tuple(kwargs['kwargs'].keys())
-
-            for single_data in data:
-                for col in columns:
-                    if blurry:# 模糊匹配
-                        if kwargs['kwargs'][col] in single_data[col]:
-                            query_list.append(data.index(single_data))
-                    else:
-                        if kwargs['kwargs'][col] == single_data[col]:
-                            query_list.append(data.index(single_data))
-                        
-                
-
-        else:
-            print("[-] 你filter的kwargs并无任何参数,您过滤您妈呢")
-        return tuple(
-            set(
-                [i for i in query_list if query_list.count(i) == len(columns)]
-            )
-        )
-
-    def clear(self):
-        if True:
-            print("该功能目前正在更新，故禁止使用. (已拦截)")
-            return
-        """clear(self)"""
+    def clear(self, sure=False):
+        if not sure:
+            confirm = input("你确定删除本数据库(同时删除云端数据)吗? (Y/N) ")
+            if confirm == "Y" or confirm == "y":
+                pass
+            else:
+                print("忽略.")
+                return
         url = f"https://gitee.com/api/v5/repos/{self.owner}/{self.repo}"
 
-        delete(
-            url=url,
-            data={"access_token":self.access_token,}
+        requests.delete(
+            url = url,
+            data = {"access_token": self.access_token,}
         )
-
-        print(f"[+] {self.repo} 清除成功")
-
+        del self
+        return True
+    
     def interact(self):
         def hotreload():
             import os, sys
