@@ -38,6 +38,26 @@ class table_objects:
                 return column
         raise ValueError("目标栏不存在.")
 
+    def create(self, datas=None):
+        if not isinstance(datas, list) and not isinstance(datas, tuple):
+            raise ValueError("参数'datas'必须为列表或元组.")
+        column = self.obj.repo.list_folder(path=self.obj.name, int=True)
+        if len(column) == 0:
+            column = 0
+        else:
+            column = max(column) + 1
+        self.obj.repo.make_folder(path=URL(self.obj.name)/column)
+        for i in range(len(datas)):
+            self.obj.repo.upload_file(
+                path = URL(self.obj.name) / column / i,
+                content = json.dumps({"content": datas[i]})
+                )
+        self.obj.sync()
+        return self.obj.columns
+
+    def delete(self):
+        self.obj.delete()
+    
     @property
     def length(self):
         return len(self.obj.columns)
@@ -45,18 +65,22 @@ class table_objects:
     def count(self):
         return len(self.obj.columns)
     
-    def filter(self, *args, **kwargs):
-        need = len(kwargs)
-        result = []
+    def filter(self, data=None):
+        '''Future Method:
+        :need = len(kwargs)
+        :result = []
+        :for column in self.obj.columns:
+        :    transit = 0
+        :    for kwarg in kwargs:
+        :        if kwargs[kwarg] in column.data:
+        :            transit += 1
+        :    if transit == need:
+        :        result.append(column)
+        ;return result
+        '''
         for column in self.obj.columns:
-            transit = 0
-            for kwarg in kwargs:
-                if kwargs[kwarg] in column.data:
-                    transit += 1
-            if transit == need:
-                result.append(column)
-        return result
-        
+            if data == column.data:
+                return column
 
 class SqleeData:
     data = None
@@ -152,6 +176,7 @@ class SqleeColumn:
 class SqleeTable:
     columns = []
     name = None
+    namespace = []
     def __init__(self, name=None, repo=None):
         if not isinstance(name, str) and not isinstance(name, URL):
             raise ValueError("参数'name'必须是字符串或URL.")
@@ -172,23 +197,10 @@ class SqleeTable:
             raise ValueError("目标栏不存在.")
 
     def insert(self, datas=None):
-        if not isinstance(datas, list) and not isinstance(datas, tuple):
-            raise ValueError("参数'datas'必须为列表或元组.")
-        column = self.repo.list_folder(path=self.name, int=True)
-        if len(column) == 0:
-            column = 0
-        else:
-            column = max(column) + 1
-        self.repo.make_folder(path=URL(self.name)/column)
-        for i in range(len(datas)):
-            self.repo.upload_file(
-                path = URL(self.name) / column / i,
-                content = json.dumps({"content": datas[i]})
-                )
-        self.sync()
-        return self.columns
+        return self.objects.create(datas=datas)
 
     def sync(self):
+        self.namespace = self.repo.get_file(path=URL(self.name)/".namespace")
         self.columns = []
         for column in self.repo.list_folder_int(path=self.name):
             self.columns.append(
